@@ -5,13 +5,13 @@ from pasteme_cli.constants import LANGUAGES, PASTEME_API_URL
 
 
 class SnippetTestCase(unittest.TestCase):
-    
-    
     def setUp(self) -> None:
         self.sample = {
             'title': 'Paste Title',
             'body': 'print("Hello")',
             'language': 'bash',
+            'theme': 'default',
+            'expiry_time': '7',
         }
 
     # TODO: Using mocks
@@ -22,4 +22,4 @@ class SnippetTestCase(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    unittest.main()
\ No newline at end of file
+    unittest.main()
